        function getT(rr,cc){
       if(rr==3 && cc==0){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260621 a 00</strong> UTC HH+180 (rango:168-192)<br><strong>control +<br>EPS</strong>';}
       if(rr==3 && cc==1){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260621 a 00</strong> UTC HH+180 (rango:168-192)<br>grupo: <strong>1</strong> representante: <strong>18</strong> miembros: 16 <strong>control</strong><br>0,2,3,5,6,8,9,17,18,20,28,29,34,40,41,48';}
       if(rr==3 && cc==2){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260621 a 00</strong> UTC HH+180 (rango:168-192)<br>grupo: <strong>2</strong> representante: <strong>50</strong> miembros: 11 <br>10,11,13,21,30,35,38,44,45,46,50';}
       if(rr==3 && cc==3){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260621 a 00</strong> UTC HH+180 (rango:168-192)<br>grupo: <strong>3</strong> representante: <strong>33</strong> miembros: 10 <br>1,7,12,16,26,27,31,32,33,49';}
       if(rr==3 && cc==4){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260621 a 00</strong> UTC HH+180 (rango:168-192)<br>grupo: <strong>4</strong> representante: <strong>24</strong> miembros: 7 <br>4,14,24,25,36,43,47';}
       if(rr==3 && cc==5){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260621 a 00</strong> UTC HH+180 (rango:168-192)<br>grupo: <strong>5</strong> representante: <strong>15</strong> miembros: 4 <br>15,22,37,42';}
       if(rr==3 && cc==6){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260621 a 00</strong> UTC HH+180 (rango:168-192)<br>grupo: <strong>6</strong> representante: <strong>19</strong> miembros: 3 <br>19,23,39';}
       if(rr==17 && cc==0){return '<strong>Probabilidad de precipitacion de 0 a 24 UTC superior a 1 mm</strong><br><br><strong>20260621 a 00</strong> UTC HH+180 (rango:168-192)<br><strong>control +<br>EPS</strong>';}
       if(rr==17 && cc==1){return '<strong>Probabilidad de precipitacion de 0 a 24 UTC superior a 1 mm</strong><br><br><strong>20260621 a 00</strong> UTC HH+180 (rango:168-192)<br>grupo: <strong>1</strong> representante: <strong>18</strong> miembros: 16 <strong>control</strong><br>0,2,3,5,6,8,9,17,18,20,28,29,34,40,41,48';}
       if(rr==17 && cc==2){return '<strong>Probabilidad de precipitacion de 0 a 24 UTC superior a 1 mm</strong><br><br><strong>20260621 a 00</strong> UTC HH+180 (rango:168-192)<br>grupo: <strong>2</strong> representante: <strong>50</strong> miembros: 11 <br>10,11,13,21,30,35,38,44,45,46,50';}
       if(rr==17 && cc==3){return '<strong>Probabilidad de precipitacion de 0 a 24 UTC superior a 1 mm</strong><br><br><strong>20260621 a 00</strong> UTC HH+180 (rango:168-192)<br>grupo: <strong>3</strong> representante: <strong>33</strong> miembros: 10 <br>1,7,12,16,26,27,31,32,33,49';}
       if(rr==17 && cc==4){return '<strong>Probabilidad de precipitacion de 0 a 24 UTC superior a 1 mm</strong><br><br><strong>20260621 a 00</strong> UTC HH+180 (rango:168-192)<br>grupo: <strong>4</strong> representante: <strong>24</strong> miembros: 7 <br>4,14,24,25,36,43,47';}
       if(rr==17 && cc==5){return '<strong>Probabilidad de precipitacion de 0 a 24 UTC superior a 1 mm</strong><br><br><strong>20260621 a 00</strong> UTC HH+180 (rango:168-192)<br>grupo: <strong>5</strong> representante: <strong>15</strong> miembros: 4 <br>15,22,37,42';}
       if(rr==17 && cc==6){return '<strong>Probabilidad de precipitacion de 0 a 24 UTC superior a 1 mm</strong><br><br><strong>20260621 a 00</strong> UTC HH+180 (rango:168-192)<br>grupo: <strong>6</strong> representante: <strong>19</strong> miembros: 3 <br>19,23,39';}
       if(rr==19 && cc==0){return '<strong>Probabilidad de precipitacion de 0 a 24 UTC superior a 2 mm</strong><br><br><strong>20260621 a 00</strong> UTC HH+180 (rango:168-192)<br><strong>control +<br>EPS</strong>';}
       if(rr==19 && cc==1){return '<strong>Probabilidad de precipitacion de 0 a 24 UTC superior a 2 mm</strong><br><br><strong>20260621 a 00</strong> UTC HH+180 (rango:168-192)<br>grupo: <strong>1</strong> representante: <strong>18</strong> miembros: 16 <strong>control</strong><br>0,2,3,5,6,8,9,17,18,20,28,29,34,40,41,48';}
       if(rr==19 && cc==2){return '<strong>Probabilidad de precipitacion de 0 a 24 UTC superior a 2 mm</strong><br><br><strong>20260621 a 00</strong> UTC HH+180 (rango:168-192)<br>grupo: <strong>2</strong> representante: <strong>50</strong> miembros: 11 <br>10,11,13,21,30,35,38,44,45,46,50';}
       if(rr==19 && cc==3){return '<strong>Probabilidad de precipitacion de 0 a 24 UTC superior a 2 mm</strong><br><br><strong>20260621 a 00</strong> UTC HH+180 (rango:168-192)<br>grupo: <strong>3</strong> representante: <strong>33</strong> miembros: 10 <br>1,7,12,16,26,27,31,32,33,49';}
       if(rr==19 && cc==4){return '<strong>Probabilidad de precipitacion de 0 a 24 UTC superior a 2 mm</strong><br><br><strong>20260621 a 00</strong> UTC HH+180 (rango:168-192)<br>grupo: <strong>4</strong> representante: <strong>24</strong> miembros: 7 <br>4,14,24,25,36,43,47';}
       if(rr==19 && cc==5){return '<strong>Probabilidad de precipitacion de 0 a 24 UTC superior a 2 mm</strong><br><br><strong>20260621 a 00</strong> UTC HH+180 (rango:168-192)<br>grupo: <strong>5</strong> representante: <strong>15</strong> miembros: 4 <br>15,22,37,42';}
       if(rr==19 && cc==6){return '<strong>Probabilidad de precipitacion de 0 a 24 UTC superior a 2 mm</strong><br><br><strong>20260621 a 00</strong> UTC HH+180 (rango:168-192)<br>grupo: <strong>6</strong> representante: <strong>19</strong> miembros: 3 <br>19,23,39';}
       if(rr==20 && cc==0){return '<strong>Probabilidad de precipitacion de 0 a 24 UTC superior a 5 mm</strong><br><br><strong>20260621 a 00</strong> UTC HH+180 (rango:168-192)<br><strong>control +<br>EPS</strong>';}
       if(rr==20 && cc==1){return '<strong>Probabilidad de precipitacion de 0 a 24 UTC superior a 5 mm</strong><br><br><strong>20260621 a 00</strong> UTC HH+180 (rango:168-192)<br>grupo: <strong>1</strong> representante: <strong>18</strong> miembros: 16 <strong>control</strong><br>0,2,3,5,6,8,9,17,18,20,28,29,34,40,41,48';}
       if(rr==20 && cc==2){return '<strong>Probabilidad de precipitacion de 0 a 24 UTC superior a 5 mm</strong><br><br><strong>20260621 a 00</strong> UTC HH+180 (rango:168-192)<br>grupo: <strong>2</strong> representante: <strong>50</strong> miembros: 11 <br>10,11,13,21,30,35,38,44,45,46,50';}
       if(rr==20 && cc==3){return '<strong>Probabilidad de precipitacion de 0 a 24 UTC superior a 5 mm</strong><br><br><strong>20260621 a 00</strong> UTC HH+180 (rango:168-192)<br>grupo: <strong>3</strong> representante: <strong>33</strong> miembros: 10 <br>1,7,12,16,26,27,31,32,33,49';}
       if(rr==20 && cc==4){return '<strong>Probabilidad de precipitacion de 0 a 24 UTC superior a 5 mm</strong><br><br><strong>20260621 a 00</strong> UTC HH+180 (rango:168-192)<br>grupo: <strong>4</strong> representante: <strong>24</strong> miembros: 7 <br>4,14,24,25,36,43,47';}
       if(rr==20 && cc==5){return '<strong>Probabilidad de precipitacion de 0 a 24 UTC superior a 5 mm</strong><br><br><strong>20260621 a 00</strong> UTC HH+180 (rango:168-192)<br>grupo: <strong>5</strong> representante: <strong>15</strong> miembros: 4 <br>15,22,37,42';}
       if(rr==20 && cc==6){return '<strong>Probabilidad de precipitacion de 0 a 24 UTC superior a 5 mm</strong><br><br><strong>20260621 a 00</strong> UTC HH+180 (rango:168-192)<br>grupo: <strong>6</strong> representante: <strong>19</strong> miembros: 3 <br>19,23,39';}
       if(rr==21 && cc==0){return '<strong>Probabilidad de precipitacion de 0 a 24 UTC superior a 10 mm</strong><br><br><strong>20260621 a 00</strong> UTC HH+180 (rango:168-192)<br><strong>control +<br>EPS</strong>';}
       if(rr==21 && cc==1){return '<strong>Probabilidad de precipitacion de 0 a 24 UTC superior a 10 mm</strong><br><br><strong>20260621 a 00</strong> UTC HH+180 (rango:168-192)<br>grupo: <strong>1</strong> representante: <strong>18</strong> miembros: 16 <strong>control</strong><br>0,2,3,5,6,8,9,17,18,20,28,29,34,40,41,48';}
       if(rr==21 && cc==2){return '<strong>Probabilidad de precipitacion de 0 a 24 UTC superior a 10 mm</strong><br><br><strong>20260621 a 00</strong> UTC HH+180 (rango:168-192)<br>grupo: <strong>2</strong> representante: <strong>50</strong> miembros: 11 <br>10,11,13,21,30,35,38,44,45,46,50';}
       if(rr==21 && cc==3){return '<strong>Probabilidad de precipitacion de 0 a 24 UTC superior a 10 mm</strong><br><br><strong>20260621 a 00</strong> UTC HH+180 (rango:168-192)<br>grupo: <strong>3</strong> representante: <strong>33</strong> miembros: 10 <br>1,7,12,16,26,27,31,32,33,49';}
       if(rr==21 && cc==4){return '<strong>Probabilidad de precipitacion de 0 a 24 UTC superior a 10 mm</strong><br><br><strong>20260621 a 00</strong> UTC HH+180 (rango:168-192)<br>grupo: <strong>4</strong> representante: <strong>24</strong> miembros: 7 <br>4,14,24,25,36,43,47';}
       if(rr==21 && cc==5){return '<strong>Probabilidad de precipitacion de 0 a 24 UTC superior a 10 mm</strong><br><br><strong>20260621 a 00</strong> UTC HH+180 (rango:168-192)<br>grupo: <strong>5</strong> representante: <strong>15</strong> miembros: 4 <br>15,22,37,42';}
       if(rr==21 && cc==6){return '<strong>Probabilidad de precipitacion de 0 a 24 UTC superior a 10 mm</strong><br><br><strong>20260621 a 00</strong> UTC HH+180 (rango:168-192)<br>grupo: <strong>6</strong> representante: <strong>19</strong> miembros: 3 <br>19,23,39';}
       if(rr==22 && cc==0){return '<strong>Probabilidad de precipitacion de 0 a 24 UTC superior a 20 mm</strong><br><br><strong>20260621 a 00</strong> UTC HH+180 (rango:168-192)<br><strong>control +<br>EPS</strong>';}
       if(rr==22 && cc==1){return '<strong>Probabilidad de precipitacion de 0 a 24 UTC superior a 20 mm</strong><br><br><strong>20260621 a 00</strong> UTC HH+180 (rango:168-192)<br>grupo: <strong>1</strong> representante: <strong>18</strong> miembros: 16 <strong>control</strong><br>0,2,3,5,6,8,9,17,18,20,28,29,34,40,41,48';}
       if(rr==22 && cc==2){return '<strong>Probabilidad de precipitacion de 0 a 24 UTC superior a 20 mm</strong><br><br><strong>20260621 a 00</strong> UTC HH+180 (rango:168-192)<br>grupo: <strong>2</strong> representante: <strong>50</strong> miembros: 11 <br>10,11,13,21,30,35,38,44,45,46,50';}
       if(rr==22 && cc==3){return '<strong>Probabilidad de precipitacion de 0 a 24 UTC superior a 20 mm</strong><br><br><strong>20260621 a 00</strong> UTC HH+180 (rango:168-192)<br>grupo: <strong>3</strong> representante: <strong>33</strong> miembros: 10 <br>1,7,12,16,26,27,31,32,33,49';}
       if(rr==22 && cc==4){return '<strong>Probabilidad de precipitacion de 0 a 24 UTC superior a 20 mm</strong><br><br><strong>20260621 a 00</strong> UTC HH+180 (rango:168-192)<br>grupo: <strong>4</strong> representante: <strong>24</strong> miembros: 7 <br>4,14,24,25,36,43,47';}
       if(rr==22 && cc==5){return '<strong>Probabilidad de precipitacion de 0 a 24 UTC superior a 20 mm</strong><br><br><strong>20260621 a 00</strong> UTC HH+180 (rango:168-192)<br>grupo: <strong>5</strong> representante: <strong>15</strong> miembros: 4 <br>15,22,37,42';}
       if(rr==22 && cc==6){return '<strong>Probabilidad de precipitacion de 0 a 24 UTC superior a 20 mm</strong><br><br><strong>20260621 a 00</strong> UTC HH+180 (rango:168-192)<br>grupo: <strong>6</strong> representante: <strong>19</strong> miembros: 3 <br>19,23,39';}
}
